@@ -12,10 +12,19 @@ def projection(edges_map, reference_map, type="no"):
                 acti_assignation_score[a] = reference_map[k][a]
 
     if not type == "no":
-        if type == "source":
-            edges_map[k] = {x: y for x, y in edges_map[k].items() if acti_assignation_map[x[0]] == k}
-        elif type == "target":
-            edges_map[k] = {x: y for x, y in edges_map[k].items() if acti_assignation_map[x[1]] == k}
+        for k in edges_map:
+            if type == "source":
+                edges_map[k] = {x: y for x, y in edges_map[k].items() if acti_assignation_map[x[0]] == k}
+            elif type == "target":
+                edges_map[k] = {x: y for x, y in edges_map[k].items() if acti_assignation_map[x[1]] == k}
+    return edges_map
+
+
+def projection_edges_freq(edges_map, events_map, min_edge_freq):
+    for k in events_map:
+        for k2 in events_map[k]:
+            if events_map[k][k2] < min_edge_freq:
+                del edges_map[k][k2]
 
     return edges_map
 
